/*
 * @author lsy
 * @date   2019-09-09
 **/
import 'dart:io';
import 'dart:typed_data';

import 'package:flutter/foundation.dart';
import 'package:flutter/src/services/platform_channel.dart';

Map<String, List<ScanImageItem>> changData(Map images) {
  Map<String, List<ScanImageItem>> newMap = new Map();
  images.forEach((k, v) {
    List<ScanImageItem> tempList = new List();
    for (var item in v) {
      ScanImageItem scanImageItem = new ScanImageItem();
      scanImageItem.path = item["path"] ?? "";
      scanImageItem.size = item["size"] ?? 0;
      scanImageItem.realPath = item["realPath"] ?? "";
      scanImageItem.isVideo = item["isVideo"] == "T" ? true : false;
      scanImageItem.during = item["during"] ?? "0";
      scanImageItem.dataToken =
          item["dataToken"] == null ? 0 : int.parse(item["dataToken"]);
      tempList.add(scanImageItem);
    }
    newMap.putIfAbsent(k, () => tempList);
  });
  return newMap;
}

const String ADD_IMAGE_CACHE = "ADD_IMAGE_CACHE";

class ScanImagePlugn {
  static Future<Map<String, List<ScanImageItem>>> scanImages(
      MethodChannel channel) async {
    var images = await channel.invokeMapMethod("scan_image_picker");
    return Future.value(compute(changData, images));
  }

  static Future<Map> nativeCamera(
      MethodChannel channel, String authority) async {
    return await channel
        .invokeMethod("native_camera", {"authority": authority});
  }

  static Future<bool> addAlbumItem(bool isVideo, String path, String realPath,
      String folderName, int during, MethodChannel channel) async {
    return await channel.invokeMethod(ADD_IMAGE_CACHE, {
      "isVideo": isVideo ? "T" : "F",
      "path": path,
      "realPath": realPath,
      "folderName": folderName,
      "during": "${during}"
    });
  }

  static Future<String> scareImg(
      MethodChannel channel, String path, int scare) async {
    return await channel
        .invokeMethod("scare_image", {"path": path, "size": scare});
  }

  static Future<bool> quitPage(MethodChannel channel) async {
    return await channel.invokeMethod("quit_page");
  }

  static Future<bool> clearCache(MethodChannel channel) async {
    return await channel.invokeMethod("clear_data");
  }

  static Future<bool> albumNeedCache(MethodChannel channel, bool need) async {
    if (Platform.isAndroid) {
      return await channel.invokeMethod("ALBUM_NEED_CACHE", need);
    } else {
      return await channel.invokeMethod("ALBUM_NEED_CACHE", need ? "T" : "F");
    }
  }

  static Future<Uint8List> getIosImageData(MethodChannel channel, String path) async {
    return await channel.invokeMethod("GET_IOS_IMAGE_DATA", path);
  }

  static Future<String> getIosVideoData(MethodChannel channel, String path) async {
    return await channel.invokeMethod("GET_IOS_IMAGE_DATA", path);
  }

  static Future<List> ios_album_path(
      MethodChannel channel, List<String> path) async {
    return await channel.invokeMethod("IOS_IMAGE_BY_PATH", path);
  }

  static Future<bool> playAlbumVideo(MethodChannel channel, String path) async {
    return await channel.invokeMethod("play_album_video", path);
  }

  static Future<bool> previewImage(MethodChannel channel, String path) async {
    return await channel.invokeMethod("PREVIEW_IMAGE", path);
  }
}

class ScanImageItem {
  String path;
  String realPath;
  String during;
  bool isVideo;
  int dataToken;
  int size;
  Uint8List data;
}
